#
# spec file for package python-easydev
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-easydev
Version:        0.13.3
Release:        1.1
Summary:        Common utilities to ease the development of Python packages
License:        BSD-3-Clause
URL:            https://github.com/cokelaer/easydev
Source:         https://github.com/cokelaer/easydev/archive/refs/tags/v%{version}.tar.gz#/easydev-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-colorama
Requires:       python-colorlog
Requires:       python-line_profiler
Requires:       python-pexpect
Requires:       python-platformdirs
Requires(post): update-alternatives
Requires(postun): update-alternatives
Recommends:     python-line_profiler
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module colorama}
BuildRequires:  %{python_module colorlog}
BuildRequires:  %{python_module line_profiler}
BuildRequires:  %{python_module pexpect}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module platformdirs}
BuildRequires:  %{python_module poetry}
BuildRequires:  %{python_module pytest-cov}
BuildRequires:  %{python_module pytest-mock}
BuildRequires:  %{python_module pytest}
# /SECTION
%python_subpackages

%description
The easydev package  provides miscellaneous functions that are
repeatedly used during the development of Python packages. The goal
is to help developers on speeding up their own dev. It has been used
also as an incubator for other packages and is stable.

%prep
%autosetup -p1 -n easydev-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# Requires network access
%pytest -k 'not test_isurl'

%files %{python_files}
%doc README.rst
%license COPYING
%{python_sitelib}/easydev
%{python_sitelib}/easydev-%{version}.dist-info

%changelog
* Mon Jan 13 2025 Steve Kowalik <steven.kowalik@suse.com>
- Update to 0.13.3:
  * Support poetry-core 2.0 by @s-t-e-v-e-n-k in #37
- Drop patch support-poetry-core-2.patch, included upstream.
* Fri Jan 10 2025 Steve Kowalik <steven.kowalik@suse.com>
- Add patch support-poetry-core-2.patch:
  * Support poetry-core 2.0 changes.
* Mon Apr 29 2024 pgajdos@suse.com
- update to 0.13.2
  * remove Python2 crumbs by @a-detiste in #29
  * remove more Python2 compat code by @a-detiste in #30
- removed patches
  - python-easydev-no-mock.patch (upstreamed)
* Tue Mar 28 2023 Steve Kowalik <steven.kowalik@suse.com>
- Remove unneeded BuildRequires on line_profiler.
* Fri Feb 10 2023 Dirk Müller <dmueller@suse.com>
- update to 0.12.1:
  * Fix a ipython warning
* Wed Mar 16 2022 pgajdos@suse.com
- do not require python-mock for build
- added patches
  fix https://github.com/cokelaer/easydev/issues/20
  + python-easydev-no-mock.patch
* Thu Sep 16 2021 Steve Kowalik <steven.kowalik@suse.com>
- Update to 0.12.0:
  * Fixing a warning from deprecated get_platform function.
  * Applied black
  * some cleanups
  * removed the package module (not used)
  * more tests
  * logging slightly improved
- Actually run tests, skipping one test that requires network.
- Stop installing easydev_buildPackage
* Tue May 26 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Fri Sep 13 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.9.38:
  * synchronized with pypi. Just an updated travis version to get rid of
    py3.3 and removing deprecated messages.
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Thu May  3 2018 toddrme2178@gmail.com
- Initial version
